# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phrase_api.api_client import ApiClient
from phrase_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class LocalesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def account_locales(self, id, **kwargs):  # noqa: E501
        """List locales used in account  # noqa: E501

        List all locales unique by locale code used across all projects within an account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_locales(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[LocalePreview1]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.account_locales_with_http_info(id, **kwargs)  # noqa: E501

    def account_locales_with_http_info(self, id, **kwargs):  # noqa: E501
        """List locales used in account  # noqa: E501

        List all locales unique by locale code used across all projects within an account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_locales_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[LocalePreview1], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'x_phrase_app_otp',
            'page',
            'per_page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_locales" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `account_locales`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/accounts/{id}/locales', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LocalePreview1]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def locale_create(self, project_id, locale_create_parameters, **kwargs):  # noqa: E501
        """Create a locale  # noqa: E501

        Create a new locale.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_create(project_id, locale_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param LocaleCreateParameters locale_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LocaleDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.locale_create_with_http_info(project_id, locale_create_parameters, **kwargs)  # noqa: E501

    def locale_create_with_http_info(self, project_id, locale_create_parameters, **kwargs):  # noqa: E501
        """Create a locale  # noqa: E501

        Create a new locale.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_create_with_http_info(project_id, locale_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param LocaleCreateParameters locale_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LocaleDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'locale_create_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method locale_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `locale_create`")  # noqa: E501
        # verify the required parameter 'locale_create_parameters' is set
        if self.api_client.client_side_validation and ('locale_create_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['locale_create_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `locale_create_parameters` when calling `locale_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'locale_create_parameters' in local_var_params:
            body_params = local_var_params['locale_create_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/locales', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LocaleDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def locale_delete(self, project_id, id, **kwargs):  # noqa: E501
        """Delete a locale  # noqa: E501

        Delete an existing locale.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_delete(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.locale_delete_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def locale_delete_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete a locale  # noqa: E501

        Delete an existing locale.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_delete_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method locale_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `locale_delete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `locale_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/locales/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def locale_download(self, project_id, id, **kwargs):  # noqa: E501
        """Download a locale  # noqa: E501

        Download a locale in a specific file format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_download(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param str file_format: File format name. See the <a href=\"https://support.phrase.com/hc/en-us/articles/5784070560412\">format guide</a> for all supported file formats.
        :param str tags: Limit results to keys tagged with a list of comma separated tag names.
        :param str tag: Limit download to tagged keys. This parameter is deprecated. Please use the \"tags\" parameter instead
        :param bool include_empty_translations: Indicates whether keys without translations should be included in the output as well.
        :param bool exclude_empty_zero_forms: Indicates whether zero forms should be included when empty in pluralized keys.
        :param bool include_translated_keys: Include translated keys in the locale file. Use in combination with include_empty_translations to obtain only untranslated keys.
        :param bool keep_notranslate_tags: Indicates whether [NOTRANSLATE] tags should be kept.
        :param bool convert_emoji: This option is obsolete. Projects that were created on or after Nov 29th 2019 or that did not contain emoji by then will not require this flag any longer since emoji are now supported natively.
        :param object format_options: Additional formatting and render options. See the <a href=\"https://support.phrase.com/hc/en-us/articles/5784070560412\">format guide</a> for a list of options available for each format. Specify format options like this: <code>...&format_options[foo]=bar</code>
        :param str encoding: Enforces a specific encoding on the file contents. Valid options are \"UTF-8\", \"UTF-16\" and \"ISO-8859-1\".
        :param bool skip_unverified_translations: Indicates whether the locale file should skip all unverified translations. This parameter is deprecated and should be replaced with <code>include_unverified_translations</code>.
        :param bool include_unverified_translations: if set to false unverified translations are excluded
        :param bool use_last_reviewed_version: If set to true the last reviewed version of a translation is used. This is only available if the review workflow (currently in beta) is enabled for the project.
        :param str fallback_locale_id: If a key has no translation in the locale being downloaded the translation in the fallback locale will be used. Provide the public ID of the locale that should be used as the fallback. Requires include_empty_translations to be set to <code>true</code>.
        :param str source_locale_id: Provides the source language of a corresponding job as the source language of the generated locale file. This parameter will be ignored unless used in combination with a <code>tag</code> parameter indicating a specific job.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.locale_download_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def locale_download_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Download a locale  # noqa: E501

        Download a locale in a specific file format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_download_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param str file_format: File format name. See the <a href=\"https://support.phrase.com/hc/en-us/articles/5784070560412\">format guide</a> for all supported file formats.
        :param str tags: Limit results to keys tagged with a list of comma separated tag names.
        :param str tag: Limit download to tagged keys. This parameter is deprecated. Please use the \"tags\" parameter instead
        :param bool include_empty_translations: Indicates whether keys without translations should be included in the output as well.
        :param bool exclude_empty_zero_forms: Indicates whether zero forms should be included when empty in pluralized keys.
        :param bool include_translated_keys: Include translated keys in the locale file. Use in combination with include_empty_translations to obtain only untranslated keys.
        :param bool keep_notranslate_tags: Indicates whether [NOTRANSLATE] tags should be kept.
        :param bool convert_emoji: This option is obsolete. Projects that were created on or after Nov 29th 2019 or that did not contain emoji by then will not require this flag any longer since emoji are now supported natively.
        :param object format_options: Additional formatting and render options. See the <a href=\"https://support.phrase.com/hc/en-us/articles/5784070560412\">format guide</a> for a list of options available for each format. Specify format options like this: <code>...&format_options[foo]=bar</code>
        :param str encoding: Enforces a specific encoding on the file contents. Valid options are \"UTF-8\", \"UTF-16\" and \"ISO-8859-1\".
        :param bool skip_unverified_translations: Indicates whether the locale file should skip all unverified translations. This parameter is deprecated and should be replaced with <code>include_unverified_translations</code>.
        :param bool include_unverified_translations: if set to false unverified translations are excluded
        :param bool use_last_reviewed_version: If set to true the last reviewed version of a translation is used. This is only available if the review workflow (currently in beta) is enabled for the project.
        :param str fallback_locale_id: If a key has no translation in the locale being downloaded the translation in the fallback locale will be used. Provide the public ID of the locale that should be used as the fallback. Requires include_empty_translations to be set to <code>true</code>.
        :param str source_locale_id: Provides the source language of a corresponding job as the source language of the generated locale file. This parameter will be ignored unless used in combination with a <code>tag</code> parameter indicating a specific job.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch',
            'file_format',
            'tags',
            'tag',
            'include_empty_translations',
            'exclude_empty_zero_forms',
            'include_translated_keys',
            'keep_notranslate_tags',
            'convert_emoji',
            'format_options',
            'encoding',
            'skip_unverified_translations',
            'include_unverified_translations',
            'use_last_reviewed_version',
            'fallback_locale_id',
            'source_locale_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method locale_download" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `locale_download`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `locale_download`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'file_format' in local_var_params and local_var_params['file_format'] is not None:  # noqa: E501
            query_params.append(('file_format', local_var_params['file_format']))  # noqa: E501
        if 'tags' in local_var_params and local_var_params['tags'] is not None:  # noqa: E501
            query_params.append(('tags', local_var_params['tags']))  # noqa: E501
        if 'tag' in local_var_params and local_var_params['tag'] is not None:  # noqa: E501
            query_params.append(('tag', local_var_params['tag']))  # noqa: E501
        if 'include_empty_translations' in local_var_params and local_var_params['include_empty_translations'] is not None:  # noqa: E501
            query_params.append(('include_empty_translations', local_var_params['include_empty_translations']))  # noqa: E501
        if 'exclude_empty_zero_forms' in local_var_params and local_var_params['exclude_empty_zero_forms'] is not None:  # noqa: E501
            query_params.append(('exclude_empty_zero_forms', local_var_params['exclude_empty_zero_forms']))  # noqa: E501
        if 'include_translated_keys' in local_var_params and local_var_params['include_translated_keys'] is not None:  # noqa: E501
            query_params.append(('include_translated_keys', local_var_params['include_translated_keys']))  # noqa: E501
        if 'keep_notranslate_tags' in local_var_params and local_var_params['keep_notranslate_tags'] is not None:  # noqa: E501
            query_params.append(('keep_notranslate_tags', local_var_params['keep_notranslate_tags']))  # noqa: E501
        if 'convert_emoji' in local_var_params and local_var_params['convert_emoji'] is not None:  # noqa: E501
            query_params.append(('convert_emoji', local_var_params['convert_emoji']))  # noqa: E501
        if 'format_options' in local_var_params and local_var_params['format_options'] is not None:  # noqa: E501
            query_params.append(('format_options', local_var_params['format_options']))  # noqa: E501
        if 'encoding' in local_var_params and local_var_params['encoding'] is not None:  # noqa: E501
            query_params.append(('encoding', local_var_params['encoding']))  # noqa: E501
        if 'skip_unverified_translations' in local_var_params and local_var_params['skip_unverified_translations'] is not None:  # noqa: E501
            query_params.append(('skip_unverified_translations', local_var_params['skip_unverified_translations']))  # noqa: E501
        if 'include_unverified_translations' in local_var_params and local_var_params['include_unverified_translations'] is not None:  # noqa: E501
            query_params.append(('include_unverified_translations', local_var_params['include_unverified_translations']))  # noqa: E501
        if 'use_last_reviewed_version' in local_var_params and local_var_params['use_last_reviewed_version'] is not None:  # noqa: E501
            query_params.append(('use_last_reviewed_version', local_var_params['use_last_reviewed_version']))  # noqa: E501
        if 'fallback_locale_id' in local_var_params and local_var_params['fallback_locale_id'] is not None:  # noqa: E501
            query_params.append(('fallback_locale_id', local_var_params['fallback_locale_id']))  # noqa: E501
        if 'source_locale_id' in local_var_params and local_var_params['source_locale_id'] is not None:  # noqa: E501
            query_params.append(('source_locale_id', local_var_params['source_locale_id']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/locales/{id}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def locale_show(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single locale  # noqa: E501

        Get details on a single locale for a given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_show(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LocaleDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.locale_show_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def locale_show_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single locale  # noqa: E501

        Get details on a single locale for a given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_show_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LocaleDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method locale_show" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `locale_show`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `locale_show`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/locales/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LocaleDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def locale_update(self, project_id, id, locale_update_parameters, **kwargs):  # noqa: E501
        """Update a locale  # noqa: E501

        Update an existing locale.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_update(project_id, id, locale_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param LocaleUpdateParameters locale_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LocaleDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.locale_update_with_http_info(project_id, id, locale_update_parameters, **kwargs)  # noqa: E501

    def locale_update_with_http_info(self, project_id, id, locale_update_parameters, **kwargs):  # noqa: E501
        """Update a locale  # noqa: E501

        Update an existing locale.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locale_update_with_http_info(project_id, id, locale_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param LocaleUpdateParameters locale_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LocaleDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'locale_update_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method locale_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `locale_update`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `locale_update`")  # noqa: E501
        # verify the required parameter 'locale_update_parameters' is set
        if self.api_client.client_side_validation and ('locale_update_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['locale_update_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `locale_update_parameters` when calling `locale_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'locale_update_parameters' in local_var_params:
            body_params = local_var_params['locale_update_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/locales/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LocaleDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def locales_list(self, project_id, **kwargs):  # noqa: E501
        """List locales  # noqa: E501

        List all locales for the given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locales_list(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str sort_by: Sort locales. Valid options are \"name_asc\", \"name_desc\", \"default_asc\", \"default_desc\".
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Locale]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.locales_list_with_http_info(project_id, **kwargs)  # noqa: E501

    def locales_list_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List locales  # noqa: E501

        List all locales for the given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.locales_list_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str sort_by: Sort locales. Valid options are \"name_asc\", \"name_desc\", \"default_asc\", \"default_desc\".
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Locale], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'sort_by',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method locales_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `locales_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'sort_by' in local_var_params and local_var_params['sort_by'] is not None:  # noqa: E501
            query_params.append(('sort_by', local_var_params['sort_by']))  # noqa: E501
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/locales', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Locale]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.distributions_api import DistributionsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestDistributionsApi(unittest.TestCase):
    """DistributionsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.distributions_api.DistributionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_distribution_create(self):
        """Test case for distribution_create

        Create a distribution  # noqa: E501
        """
        pass

    def test_distribution_delete(self):
        """Test case for distribution_delete

        Delete a distribution  # noqa: E501
        """
        pass

    def test_distribution_show(self):
        """Test case for distribution_show

        Get a single distribution  # noqa: E501
        """
        pass

    def test_distribution_update(self):
        """Test case for distribution_update

        Update a distribution  # noqa: E501
        """
        pass

    def test_distributions_list(self):
        """Test case for distributions_list

        List distributions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.member_project_detail import MemberProjectDetail  # noqa: E501
from phrase_api.rest import ApiException

class TestMemberProjectDetail(unittest.TestCase):
    """MemberProjectDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MemberProjectDetail
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.member_project_detail.MemberProjectDetail()  # noqa: E501
        if include_optional :
            return MemberProjectDetail(
                id = '0', 
                email = '0', 
                username = '0', 
                role = '0', 
                projects = [
                    null
                    ], 
                permissions = None, 
                locale_ids = [
                    '0'
                    ], 
                default_locale_codes = [
                    '0'
                    ], 
                spaces = [
                    phrase_api.models.member_spaces.member_spaces(
                        id = '0', 
                        name = '0', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        projects_count = 56, )
                    ], 
                project_roles = [
                    phrase_api.models.member_project_detail_project_roles.member_project_detail_project_roles(
                        project_id = '0', 
                        role = '0', )
                    ]
            )
        else :
            return MemberProjectDetail(
        )

    def testMemberProjectDetail(self):
        """Test MemberProjectDetail"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class GitlabSync(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'project_id': 'str',
        'gitlab_project_id': 'int',
        'gitlab_branch_name': 'str',
        'auto_import': 'bool',
        'auto_import_secret': 'str',
        'auto_import_url': 'str',
        'self_hosted_api_url': 'str',
        'last_exported_at': 'datetime',
        'last_imported_at': 'datetime',
        'last_status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'project_id': 'project_id',
        'gitlab_project_id': 'gitlab_project_id',
        'gitlab_branch_name': 'gitlab_branch_name',
        'auto_import': 'auto_import',
        'auto_import_secret': 'auto_import_secret',
        'auto_import_url': 'auto_import_url',
        'self_hosted_api_url': 'self_hosted_api_url',
        'last_exported_at': 'last_exported_at',
        'last_imported_at': 'last_imported_at',
        'last_status': 'last_status'
    }

    def __init__(self, id=None, project_id=None, gitlab_project_id=None, gitlab_branch_name=None, auto_import=None, auto_import_secret=None, auto_import_url=None, self_hosted_api_url=None, last_exported_at=None, last_imported_at=None, last_status=None, local_vars_configuration=None):  # noqa: E501
        """GitlabSync - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._project_id = None
        self._gitlab_project_id = None
        self._gitlab_branch_name = None
        self._auto_import = None
        self._auto_import_secret = None
        self._auto_import_url = None
        self._self_hosted_api_url = None
        self._last_exported_at = None
        self._last_imported_at = None
        self._last_status = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if project_id is not None:
            self.project_id = project_id
        if gitlab_project_id is not None:
            self.gitlab_project_id = gitlab_project_id
        if gitlab_branch_name is not None:
            self.gitlab_branch_name = gitlab_branch_name
        if auto_import is not None:
            self.auto_import = auto_import
        if auto_import_secret is not None:
            self.auto_import_secret = auto_import_secret
        if auto_import_url is not None:
            self.auto_import_url = auto_import_url
        if self_hosted_api_url is not None:
            self.self_hosted_api_url = self_hosted_api_url
        if last_exported_at is not None:
            self.last_exported_at = last_exported_at
        if last_imported_at is not None:
            self.last_imported_at = last_imported_at
        if last_status is not None:
            self.last_status = last_status

    @property
    def id(self):
        """Gets the id of this GitlabSync.  # noqa: E501


        :return: The id of this GitlabSync.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GitlabSync.


        :param id: The id of this GitlabSync.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def project_id(self):
        """Gets the project_id of this GitlabSync.  # noqa: E501


        :return: The project_id of this GitlabSync.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this GitlabSync.


        :param project_id: The project_id of this GitlabSync.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def gitlab_project_id(self):
        """Gets the gitlab_project_id of this GitlabSync.  # noqa: E501


        :return: The gitlab_project_id of this GitlabSync.  # noqa: E501
        :rtype: int
        """
        return self._gitlab_project_id

    @gitlab_project_id.setter
    def gitlab_project_id(self, gitlab_project_id):
        """Sets the gitlab_project_id of this GitlabSync.


        :param gitlab_project_id: The gitlab_project_id of this GitlabSync.  # noqa: E501
        :type: int
        """

        self._gitlab_project_id = gitlab_project_id

    @property
    def gitlab_branch_name(self):
        """Gets the gitlab_branch_name of this GitlabSync.  # noqa: E501


        :return: The gitlab_branch_name of this GitlabSync.  # noqa: E501
        :rtype: str
        """
        return self._gitlab_branch_name

    @gitlab_branch_name.setter
    def gitlab_branch_name(self, gitlab_branch_name):
        """Sets the gitlab_branch_name of this GitlabSync.


        :param gitlab_branch_name: The gitlab_branch_name of this GitlabSync.  # noqa: E501
        :type: str
        """

        self._gitlab_branch_name = gitlab_branch_name

    @property
    def auto_import(self):
        """Gets the auto_import of this GitlabSync.  # noqa: E501


        :return: The auto_import of this GitlabSync.  # noqa: E501
        :rtype: bool
        """
        return self._auto_import

    @auto_import.setter
    def auto_import(self, auto_import):
        """Sets the auto_import of this GitlabSync.


        :param auto_import: The auto_import of this GitlabSync.  # noqa: E501
        :type: bool
        """

        self._auto_import = auto_import

    @property
    def auto_import_secret(self):
        """Gets the auto_import_secret of this GitlabSync.  # noqa: E501


        :return: The auto_import_secret of this GitlabSync.  # noqa: E501
        :rtype: str
        """
        return self._auto_import_secret

    @auto_import_secret.setter
    def auto_import_secret(self, auto_import_secret):
        """Sets the auto_import_secret of this GitlabSync.


        :param auto_import_secret: The auto_import_secret of this GitlabSync.  # noqa: E501
        :type: str
        """

        self._auto_import_secret = auto_import_secret

    @property
    def auto_import_url(self):
        """Gets the auto_import_url of this GitlabSync.  # noqa: E501


        :return: The auto_import_url of this GitlabSync.  # noqa: E501
        :rtype: str
        """
        return self._auto_import_url

    @auto_import_url.setter
    def auto_import_url(self, auto_import_url):
        """Sets the auto_import_url of this GitlabSync.


        :param auto_import_url: The auto_import_url of this GitlabSync.  # noqa: E501
        :type: str
        """

        self._auto_import_url = auto_import_url

    @property
    def self_hosted_api_url(self):
        """Gets the self_hosted_api_url of this GitlabSync.  # noqa: E501


        :return: The self_hosted_api_url of this GitlabSync.  # noqa: E501
        :rtype: str
        """
        return self._self_hosted_api_url

    @self_hosted_api_url.setter
    def self_hosted_api_url(self, self_hosted_api_url):
        """Sets the self_hosted_api_url of this GitlabSync.


        :param self_hosted_api_url: The self_hosted_api_url of this GitlabSync.  # noqa: E501
        :type: str
        """

        self._self_hosted_api_url = self_hosted_api_url

    @property
    def last_exported_at(self):
        """Gets the last_exported_at of this GitlabSync.  # noqa: E501


        :return: The last_exported_at of this GitlabSync.  # noqa: E501
        :rtype: datetime
        """
        return self._last_exported_at

    @last_exported_at.setter
    def last_exported_at(self, last_exported_at):
        """Sets the last_exported_at of this GitlabSync.


        :param last_exported_at: The last_exported_at of this GitlabSync.  # noqa: E501
        :type: datetime
        """

        self._last_exported_at = last_exported_at

    @property
    def last_imported_at(self):
        """Gets the last_imported_at of this GitlabSync.  # noqa: E501


        :return: The last_imported_at of this GitlabSync.  # noqa: E501
        :rtype: datetime
        """
        return self._last_imported_at

    @last_imported_at.setter
    def last_imported_at(self, last_imported_at):
        """Sets the last_imported_at of this GitlabSync.


        :param last_imported_at: The last_imported_at of this GitlabSync.  # noqa: E501
        :type: datetime
        """

        self._last_imported_at = last_imported_at

    @property
    def last_status(self):
        """Gets the last_status of this GitlabSync.  # noqa: E501


        :return: The last_status of this GitlabSync.  # noqa: E501
        :rtype: str
        """
        return self._last_status

    @last_status.setter
    def last_status(self, last_status):
        """Sets the last_status of this GitlabSync.


        :param last_status: The last_status of this GitlabSync.  # noqa: E501
        :type: str
        """

        self._last_status = last_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GitlabSync):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GitlabSync):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.spaces_api import SpacesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestSpacesApi(unittest.TestCase):
    """SpacesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.spaces_api.SpacesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_space_create(self):
        """Test case for space_create

        Create a Space  # noqa: E501
        """
        pass

    def test_space_delete(self):
        """Test case for space_delete

        Delete Space  # noqa: E501
        """
        pass

    def test_space_show(self):
        """Test case for space_show

        Get Space  # noqa: E501
        """
        pass

    def test_space_update(self):
        """Test case for space_update

        Update Space  # noqa: E501
        """
        pass

    def test_spaces_list(self):
        """Test case for spaces_list

        List Spaces  # noqa: E501
        """
        pass

    def test_spaces_projects_create(self):
        """Test case for spaces_projects_create

        Add Project  # noqa: E501
        """
        pass

    def test_spaces_projects_delete(self):
        """Test case for spaces_projects_delete

        Remove Project  # noqa: E501
        """
        pass

    def test_spaces_projects_list(self):
        """Test case for spaces_projects_list

        List Projects  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class JobCreateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'name': 'str',
        'source_locale_id': 'str',
        'briefing': 'str',
        'due_date': 'datetime',
        'ticket_url': 'str',
        'tags': 'list[str]',
        'translation_key_ids': 'list[str]',
        'job_template_id': 'str'
    }

    attribute_map = {
        'branch': 'branch',
        'name': 'name',
        'source_locale_id': 'source_locale_id',
        'briefing': 'briefing',
        'due_date': 'due_date',
        'ticket_url': 'ticket_url',
        'tags': 'tags',
        'translation_key_ids': 'translation_key_ids',
        'job_template_id': 'job_template_id'
    }

    def __init__(self, branch=None, name=None, source_locale_id=None, briefing=None, due_date=None, ticket_url=None, tags=None, translation_key_ids=None, job_template_id=None, local_vars_configuration=None):  # noqa: E501
        """JobCreateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._name = None
        self._source_locale_id = None
        self._briefing = None
        self._due_date = None
        self._ticket_url = None
        self._tags = None
        self._translation_key_ids = None
        self._job_template_id = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if name is not None:
            self.name = name
        if source_locale_id is not None:
            self.source_locale_id = source_locale_id
        if briefing is not None:
            self.briefing = briefing
        if due_date is not None:
            self.due_date = due_date
        if ticket_url is not None:
            self.ticket_url = ticket_url
        if tags is not None:
            self.tags = tags
        if translation_key_ids is not None:
            self.translation_key_ids = translation_key_ids
        if job_template_id is not None:
            self.job_template_id = job_template_id

    @property
    def branch(self):
        """Gets the branch of this JobCreateParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this JobCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this JobCreateParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this JobCreateParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def name(self):
        """Gets the name of this JobCreateParameters.  # noqa: E501

        Job name  # noqa: E501

        :return: The name of this JobCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobCreateParameters.

        Job name  # noqa: E501

        :param name: The name of this JobCreateParameters.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def source_locale_id(self):
        """Gets the source_locale_id of this JobCreateParameters.  # noqa: E501

        The API id of the source language  # noqa: E501

        :return: The source_locale_id of this JobCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._source_locale_id

    @source_locale_id.setter
    def source_locale_id(self, source_locale_id):
        """Sets the source_locale_id of this JobCreateParameters.

        The API id of the source language  # noqa: E501

        :param source_locale_id: The source_locale_id of this JobCreateParameters.  # noqa: E501
        :type: str
        """

        self._source_locale_id = source_locale_id

    @property
    def briefing(self):
        """Gets the briefing of this JobCreateParameters.  # noqa: E501

        Briefing for the translators  # noqa: E501

        :return: The briefing of this JobCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._briefing

    @briefing.setter
    def briefing(self, briefing):
        """Sets the briefing of this JobCreateParameters.

        Briefing for the translators  # noqa: E501

        :param briefing: The briefing of this JobCreateParameters.  # noqa: E501
        :type: str
        """

        self._briefing = briefing

    @property
    def due_date(self):
        """Gets the due_date of this JobCreateParameters.  # noqa: E501

        Date the job should be finished  # noqa: E501

        :return: The due_date of this JobCreateParameters.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this JobCreateParameters.

        Date the job should be finished  # noqa: E501

        :param due_date: The due_date of this JobCreateParameters.  # noqa: E501
        :type: datetime
        """

        self._due_date = due_date

    @property
    def ticket_url(self):
        """Gets the ticket_url of this JobCreateParameters.  # noqa: E501

        URL to a ticket for this job (e.g. Jira, Trello)  # noqa: E501

        :return: The ticket_url of this JobCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._ticket_url

    @ticket_url.setter
    def ticket_url(self, ticket_url):
        """Sets the ticket_url of this JobCreateParameters.

        URL to a ticket for this job (e.g. Jira, Trello)  # noqa: E501

        :param ticket_url: The ticket_url of this JobCreateParameters.  # noqa: E501
        :type: str
        """

        self._ticket_url = ticket_url

    @property
    def tags(self):
        """Gets the tags of this JobCreateParameters.  # noqa: E501

        tags of keys that should be included within the job  # noqa: E501

        :return: The tags of this JobCreateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this JobCreateParameters.

        tags of keys that should be included within the job  # noqa: E501

        :param tags: The tags of this JobCreateParameters.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def translation_key_ids(self):
        """Gets the translation_key_ids of this JobCreateParameters.  # noqa: E501

        ids of keys that should be included within the job  # noqa: E501

        :return: The translation_key_ids of this JobCreateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._translation_key_ids

    @translation_key_ids.setter
    def translation_key_ids(self, translation_key_ids):
        """Sets the translation_key_ids of this JobCreateParameters.

        ids of keys that should be included within the job  # noqa: E501

        :param translation_key_ids: The translation_key_ids of this JobCreateParameters.  # noqa: E501
        :type: list[str]
        """

        self._translation_key_ids = translation_key_ids

    @property
    def job_template_id(self):
        """Gets the job_template_id of this JobCreateParameters.  # noqa: E501

        id of a job template you would like to model the created job after. Any manually added parameters will take preference over template attributes.  # noqa: E501

        :return: The job_template_id of this JobCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._job_template_id

    @job_template_id.setter
    def job_template_id(self, job_template_id):
        """Sets the job_template_id of this JobCreateParameters.

        id of a job template you would like to model the created job after. Any manually added parameters will take preference over template attributes.  # noqa: E501

        :param job_template_id: The job_template_id of this JobCreateParameters.  # noqa: E501
        :type: str
        """

        self._job_template_id = job_template_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobCreateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobCreateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.job_comments_api import JobCommentsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestJobCommentsApi(unittest.TestCase):
    """JobCommentsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.job_comments_api.JobCommentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_job_comment_create(self):
        """Test case for job_comment_create

        Create a job comment  # noqa: E501
        """
        pass

    def test_job_comment_delete(self):
        """Test case for job_comment_delete

        Delete a job comment  # noqa: E501
        """
        pass

    def test_job_comment_show(self):
        """Test case for job_comment_show

        Get a single job comment  # noqa: E501
        """
        pass

    def test_job_comment_update(self):
        """Test case for job_comment_update

        Update a job comment  # noqa: E501
        """
        pass

    def test_job_comments_list(self):
        """Test case for job_comments_list

        List job comments  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class BitbucketSync(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'repository_name': 'str',
        'last_export_to_bitbucket_at': 'datetime',
        'last_import_from_bitbucket_at': 'datetime',
        'valid_phraseapp_yaml': 'bool',
        'phraseapp_projects': 'list[ProjectShort]'
    }

    attribute_map = {
        'id': 'id',
        'repository_name': 'repository_name',
        'last_export_to_bitbucket_at': 'last_export_to_bitbucket_at',
        'last_import_from_bitbucket_at': 'last_import_from_bitbucket_at',
        'valid_phraseapp_yaml': 'valid_phraseapp_yaml',
        'phraseapp_projects': 'phraseapp_projects'
    }

    def __init__(self, id=None, repository_name=None, last_export_to_bitbucket_at=None, last_import_from_bitbucket_at=None, valid_phraseapp_yaml=None, phraseapp_projects=None, local_vars_configuration=None):  # noqa: E501
        """BitbucketSync - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._repository_name = None
        self._last_export_to_bitbucket_at = None
        self._last_import_from_bitbucket_at = None
        self._valid_phraseapp_yaml = None
        self._phraseapp_projects = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if repository_name is not None:
            self.repository_name = repository_name
        if last_export_to_bitbucket_at is not None:
            self.last_export_to_bitbucket_at = last_export_to_bitbucket_at
        if last_import_from_bitbucket_at is not None:
            self.last_import_from_bitbucket_at = last_import_from_bitbucket_at
        if valid_phraseapp_yaml is not None:
            self.valid_phraseapp_yaml = valid_phraseapp_yaml
        if phraseapp_projects is not None:
            self.phraseapp_projects = phraseapp_projects

    @property
    def id(self):
        """Gets the id of this BitbucketSync.  # noqa: E501


        :return: The id of this BitbucketSync.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BitbucketSync.


        :param id: The id of this BitbucketSync.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def repository_name(self):
        """Gets the repository_name of this BitbucketSync.  # noqa: E501


        :return: The repository_name of this BitbucketSync.  # noqa: E501
        :rtype: str
        """
        return self._repository_name

    @repository_name.setter
    def repository_name(self, repository_name):
        """Sets the repository_name of this BitbucketSync.


        :param repository_name: The repository_name of this BitbucketSync.  # noqa: E501
        :type: str
        """

        self._repository_name = repository_name

    @property
    def last_export_to_bitbucket_at(self):
        """Gets the last_export_to_bitbucket_at of this BitbucketSync.  # noqa: E501


        :return: The last_export_to_bitbucket_at of this BitbucketSync.  # noqa: E501
        :rtype: datetime
        """
        return self._last_export_to_bitbucket_at

    @last_export_to_bitbucket_at.setter
    def last_export_to_bitbucket_at(self, last_export_to_bitbucket_at):
        """Sets the last_export_to_bitbucket_at of this BitbucketSync.


        :param last_export_to_bitbucket_at: The last_export_to_bitbucket_at of this BitbucketSync.  # noqa: E501
        :type: datetime
        """

        self._last_export_to_bitbucket_at = last_export_to_bitbucket_at

    @property
    def last_import_from_bitbucket_at(self):
        """Gets the last_import_from_bitbucket_at of this BitbucketSync.  # noqa: E501


        :return: The last_import_from_bitbucket_at of this BitbucketSync.  # noqa: E501
        :rtype: datetime
        """
        return self._last_import_from_bitbucket_at

    @last_import_from_bitbucket_at.setter
    def last_import_from_bitbucket_at(self, last_import_from_bitbucket_at):
        """Sets the last_import_from_bitbucket_at of this BitbucketSync.


        :param last_import_from_bitbucket_at: The last_import_from_bitbucket_at of this BitbucketSync.  # noqa: E501
        :type: datetime
        """

        self._last_import_from_bitbucket_at = last_import_from_bitbucket_at

    @property
    def valid_phraseapp_yaml(self):
        """Gets the valid_phraseapp_yaml of this BitbucketSync.  # noqa: E501


        :return: The valid_phraseapp_yaml of this BitbucketSync.  # noqa: E501
        :rtype: bool
        """
        return self._valid_phraseapp_yaml

    @valid_phraseapp_yaml.setter
    def valid_phraseapp_yaml(self, valid_phraseapp_yaml):
        """Sets the valid_phraseapp_yaml of this BitbucketSync.


        :param valid_phraseapp_yaml: The valid_phraseapp_yaml of this BitbucketSync.  # noqa: E501
        :type: bool
        """

        self._valid_phraseapp_yaml = valid_phraseapp_yaml

    @property
    def phraseapp_projects(self):
        """Gets the phraseapp_projects of this BitbucketSync.  # noqa: E501


        :return: The phraseapp_projects of this BitbucketSync.  # noqa: E501
        :rtype: list[ProjectShort]
        """
        return self._phraseapp_projects

    @phraseapp_projects.setter
    def phraseapp_projects(self, phraseapp_projects):
        """Sets the phraseapp_projects of this BitbucketSync.


        :param phraseapp_projects: The phraseapp_projects of this BitbucketSync.  # noqa: E501
        :type: list[ProjectShort]
        """

        self._phraseapp_projects = phraseapp_projects

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BitbucketSync):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BitbucketSync):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.project_create_parameters import ProjectCreateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestProjectCreateParameters(unittest.TestCase):
    """ProjectCreateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProjectCreateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.project_create_parameters.ProjectCreateParameters()  # noqa: E501
        if include_optional :
            return ProjectCreateParameters(
                name = 'My Android Project', 
                main_format = 'yml', 
                shares_translation_memory = True, 
                project_image = bytes(b'blah'), 
                remove_project_image = True, 
                account_id = 'abcd1234', 
                source_project_id = 'abcd1234', 
                workflow = 'review', 
                machine_translation_enabled = True, 
                enable_branching = True, 
                protect_master_branch = True, 
                enable_all_data_type_translation_keys_for_translators = True, 
                enable_icu_message_format = True, 
                zero_plural_form_enabled = True, 
                autotranslate_enabled = True, 
                autotranslate_check_new_translation_keys = True, 
                autotranslate_check_new_uploads = True, 
                autotranslate_check_new_locales = True, 
                autotranslate_mark_as_unverified = True, 
                autotranslate_use_machine_translation = True, 
                autotranslate_use_translation_memory = True, 
                smart_suggest_enabled = True, 
                smart_suggest_use_glossary = True, 
                smart_suggest_use_machine_translation = True
            )
        else :
            return ProjectCreateParameters(
        )

    def testProjectCreateParameters(self):
        """Test ProjectCreateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.key_update_parameters import KeyUpdateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestKeyUpdateParameters(unittest.TestCase):
    """KeyUpdateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test KeyUpdateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.key_update_parameters.KeyUpdateParameters()  # noqa: E501
        if include_optional :
            return KeyUpdateParameters(
                branch = 'my-feature-branch', 
                name = 'home.index.headline', 
                description = 'Some description worth knowing...', 
                plural = True, 
                name_plural = 'home.index.headlines', 
                data_type = 'number', 
                tags = 'awesome-feature,needs-proofreading', 
                max_characters_allowed = 140, 
                screenshot = bytes(b'blah'), 
                remove_screenshot = True, 
                unformatted = True, 
                xml_space_preserve = True, 
                original_file = '0', 
                localized_format_string = '0', 
                localized_format_key = '0'
            )
        else :
            return KeyUpdateParameters(
        )

    def testKeyUpdateParameters(self):
        """Test KeyUpdateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.locale_statistics import LocaleStatistics  # noqa: E501
from phrase_api.rest import ApiException

class TestLocaleStatistics(unittest.TestCase):
    """LocaleStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LocaleStatistics
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.locale_statistics.LocaleStatistics()  # noqa: E501
        if include_optional :
            return LocaleStatistics(
                keys_total_count = 56, 
                keys_untranslated_count = 56, 
                words_total_count = 56, 
                translations_completed_count = 56, 
                translations_unverified_count = 56, 
                unverified_words_count = 56, 
                missing_words_count = 56
            )
        else :
            return LocaleStatistics(
        )

    def testLocaleStatistics(self):
        """Test LocaleStatistics"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.job_locales_api import JobLocalesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestJobLocalesApi(unittest.TestCase):
    """JobLocalesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.job_locales_api.JobLocalesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_job_locale_complete(self):
        """Test case for job_locale_complete

        Complete a job locale  # noqa: E501
        """
        pass

    def test_job_locale_complete_review(self):
        """Test case for job_locale_complete_review

        Review a job locale  # noqa: E501
        """
        pass

    def test_job_locale_delete(self):
        """Test case for job_locale_delete

        Delete a job locale  # noqa: E501
        """
        pass

    def test_job_locale_reopen(self):
        """Test case for job_locale_reopen

        Reopen a job locale  # noqa: E501
        """
        pass

    def test_job_locale_show(self):
        """Test case for job_locale_show

        Get a single job locale  # noqa: E501
        """
        pass

    def test_job_locale_update(self):
        """Test case for job_locale_update

        Update a job locale  # noqa: E501
        """
        pass

    def test_job_locales_create(self):
        """Test case for job_locales_create

        Create a job locale  # noqa: E501
        """
        pass

    def test_job_locales_list(self):
        """Test case for job_locales_list

        List job locales  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
